package javax.management.modelmbean;

import java.util.HashMap;
import sun.misc.SharedSecrets;
import javax.management.ObjectName;
import javax.management.MBeanServerFactory;
import javax.management.loading.ClassLoaderRepository;
import javax.management.AttributeChangeNotification;
import java.util.Vector;
import javax.management.AttributeChangeNotificationFilter;
import javax.management.Notification;
import javax.management.ListenerNotFoundException;
import javax.management.NotificationFilter;
import javax.management.NotificationListener;
import java.io.PrintStream;
import java.io.FileOutputStream;
import java.util.Iterator;
import javax.management.Attribute;
import javax.management.AttributeList;
import javax.management.AttributeNotFoundException;
import javax.management.InvalidAttributeValueException;
import java.util.HashSet;
import javax.management.RuntimeErrorException;
import java.lang.reflect.InvocationTargetException;
import sun.reflect.misc.MethodUtil;
import java.lang.reflect.Method;
import javax.management.ReflectionException;
import sun.reflect.misc.ReflectUtil;
import java.security.PrivilegedAction;
import javax.management.MBeanNotificationInfo;
import javax.management.MBeanOperationInfo;
import javax.management.MBeanConstructorInfo;
import javax.management.MBeanAttributeInfo;
import javax.management.MBeanInfo;
import java.util.Date;
import javax.management.Descriptor;
import javax.management.ServiceNotFoundException;
import javax.management.InstanceNotFoundException;
import javax.management.RuntimeOperationsException;
import javax.management.MBeanException;
import java.util.logging.Level;
import com.sun.jmx.defaults.JmxProperties;
import java.security.AccessController;
import java.util.Set;
import java.util.Map;
import java.security.AccessControlContext;
import sun.misc.JavaSecurityAccess;
import javax.management.MBeanServer;
import javax.management.NotificationBroadcasterSupport;
import javax.management.NotificationEmitter;
import javax.management.MBeanRegistration;

public class RequiredModelMBean implements ModelMBean, MBeanRegistration, NotificationEmitter
{
    ModelMBeanInfo modelMBeanInfo;
    private NotificationBroadcasterSupport generalBroadcaster;
    private NotificationBroadcasterSupport attributeBroadcaster;
    private Object managedResource;
    private boolean registered;
    private transient MBeanServer server;
    private static final JavaSecurityAccess javaSecurityAccess;
    private final AccessControlContext acc;
    private static final Class<?>[] primitiveClasses;
    private static final Map<String, Class<?>> primitiveClassMap;
    private static Set<String> rmmbMethodNames;
    private static final String[] primitiveTypes;
    private static final String[] primitiveWrappers;
    
    public RequiredModelMBean() throws MBeanException, RuntimeOperationsException {
        this.generalBroadcaster = null;
        this.attributeBroadcaster = null;
        this.managedResource = null;
        this.registered = false;
        this.server = null;
        this.acc = AccessController.getContext();
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "RequiredModelMBean()", "Entry");
        }
        this.modelMBeanInfo = this.createDefaultModelMBeanInfo();
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "RequiredModelMBean()", "Exit");
        }
    }
    
    public RequiredModelMBean(ModelMBeanInfo modelMBeanInfo) throws MBeanException, RuntimeOperationsException {
        this.generalBroadcaster = null;
        this.attributeBroadcaster = null;
        this.managedResource = null;
        this.registered = false;
        this.server = null;
        this.acc = AccessController.getContext();
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "RequiredModelMBean(MBeanInfo)", "Entry");
        }
        this.setModelMBeanInfo(modelMBeanInfo);
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "RequiredModelMBean(MBeanInfo)", "Exit");
        }
    }
    
    @Override
    public void setModelMBeanInfo(ModelMBeanInfo modelMBeanInfo) throws MBeanException, RuntimeOperationsException {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setModelMBeanInfo(ModelMBeanInfo)", "Entry");
        }
        if (modelMBeanInfo == null) {
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setModelMBeanInfo(ModelMBeanInfo)", "ModelMBeanInfo is null: Raising exception.");
            }
            throw new RuntimeOperationsException(new IllegalArgumentException("ModelMBeanInfo must not be null"), "Exception occurred trying to initialize the ModelMBeanInfo of the RequiredModelMBean");
        }
        else if (this.registered) {
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setModelMBeanInfo(ModelMBeanInfo)", "RequiredMBean is registered: Raising exception.");
            }
            throw new RuntimeOperationsException(new IllegalStateException("cannot call setModelMBeanInfo while ModelMBean is registered"), "Exception occurred trying to set the ModelMBeanInfo of the RequiredModelMBean");
        }
        else {
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setModelMBeanInfo(ModelMBeanInfo)", "Setting ModelMBeanInfo to " + this.printModelMBeanInfo(modelMBeanInfo));
                int length = 0;
                if (modelMBeanInfo.getNotifications() != null) {
                    length = modelMBeanInfo.getNotifications().length;
                }
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setModelMBeanInfo(ModelMBeanInfo)", "ModelMBeanInfo notifications has " + length + " elements");
            }
            this.modelMBeanInfo = (ModelMBeanInfo)modelMBeanInfo.clone();
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setModelMBeanInfo(ModelMBeanInfo)", "set mbeanInfo to: " + this.printModelMBeanInfo(this.modelMBeanInfo));
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setModelMBeanInfo(ModelMBeanInfo)", "Exit");
            }
            return;
        }
    }
    
    @Override
    public void setManagedResource(Object managedResource, String str) throws MBeanException, RuntimeOperationsException, InstanceNotFoundException, InvalidTargetObjectTypeException {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setManagedResource(Object,String)", "Entry");
        }
        if (str == null || !str.equalsIgnoreCase("objectReference")) {
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setManagedResource(Object,String)", "Managed Resource Type is not supported: " + str);
            }
            throw new InvalidTargetObjectTypeException(str);
        }
        else {
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setManagedResource(Object,String)", "Managed Resource is valid");
            }
            this.managedResource = managedResource;
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setManagedResource(Object, String)", "Exit");
            }
            return;
        }
    }
    
    @Override
    public void load() throws MBeanException, RuntimeOperationsException, InstanceNotFoundException {
        ServiceNotFoundException e = new ServiceNotFoundException("Persistence not supported for this MBean");
        throw new MBeanException(e, e.getMessage());
    }
    
    @Override
    public void store() throws MBeanException, RuntimeOperationsException, InstanceNotFoundException {
        ServiceNotFoundException e = new ServiceNotFoundException("Persistence not supported for this MBean");
        throw new MBeanException(e, e.getMessage());
    }
    
    private Object resolveForCacheValue(Descriptor obj) throws MBeanException, RuntimeOperationsException {
        int loggable = JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER);
        if (!(loggable == 0)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "Entry");
        }
        Object o = null;
        if (obj == null) {
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "Input Descriptor is null");
                return o;
            }
            return o;
        }
        else {
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "descriptor is " + obj);
            }
            Descriptor mBeanDescriptor = this.modelMBeanInfo.getMBeanDescriptor();
            if (mBeanDescriptor == null && loggable) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "MBean Descriptor is null");
            }
            Object fieldValue = obj.getFieldValue("currencyTimeLimit");
            String s;
            if (fieldValue != null) {
                s = fieldValue.toString();
            }
            else {
                s = null;
            }
            if (s == null && mBeanDescriptor != null) {
                Object fieldValue2 = mBeanDescriptor.getFieldValue("currencyTimeLimit");
                if (fieldValue2 != null) {
                    s = fieldValue2.toString();
                }
                else {
                    s = null;
                }
            }
            if (s != null) {
                if (!(loggable == 0)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "currencyTimeLimit: " + s);
                }
                long n = (long)new Long(s) * 1000L;
                int b;
                int b2;
                if (n < 0L) {
                    b = false;
                    b2 = true;
                    if (!(loggable == 0)) {
                        JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", n + ": never Cached");
                    }
                }
                else if (n == 0L) {
                    b = true;
                    b2 = false;
                    if (!(loggable == 0)) {
                        JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "always valid Cache");
                    }
                }
                else {
                    Object fieldValue3 = obj.getFieldValue("lastUpdatedTimeStamp");
                    String string;
                    if (fieldValue3 != null) {
                        string = fieldValue3.toString();
                    }
                    else {
                        string = null;
                    }
                    if (!(loggable == 0)) {
                        JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "lastUpdatedTimeStamp: " + string);
                    }
                    if (string == null) {
                        string = "0";
                    }
                    long longValue = (long)new Long(string);
                    if (!(loggable == 0)) {
                        JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "currencyPeriod:" + n + " lastUpdatedTimeStamp:" + longValue);
                    }
                    long time = new Date().getTime();
                    if (time < longValue + n) {
                        b = true;
                        b2 = false;
                        if (!(loggable == 0)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", " timed valid Cache for " + time + " < " + (longValue + n));
                        }
                    }
                    else {
                        b = false;
                        b2 = true;
                        if (!(loggable == 0)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "timed expired cache for " + time + " > " + (longValue + n));
                        }
                    }
                }
                if (!(loggable == 0)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "returnCachedValue:" + (boolean)b + " resetValue: " + (boolean)b2);
                }
                if (b != 0) {
                    Object fieldValue4 = obj.getFieldValue("value");
                    if (fieldValue4 != null) {
                        o = fieldValue4;
                        if (!(loggable == 0)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "valid Cache value: " + fieldValue4);
                        }
                    }
                    else {
                        o = null;
                        if (!(loggable == 0)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "no Cached value");
                        }
                    }
                }
                if (b2 != 0) {
                    obj.removeField("lastUpdatedTimeStamp");
                    obj.removeField("value");
                    o = null;
                    this.modelMBeanInfo.setDescriptor(obj, null);
                    if (!(loggable == 0)) {
                        JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "reset cached value to null");
                    }
                }
            }
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveForCacheValue(Descriptor)", "Exit");
                return o;
            }
            return o;
        }
    }
    
    @Override
    public MBeanInfo getMBeanInfo() {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getMBeanInfo()", "Entry");
        }
        if (this.modelMBeanInfo == null) {
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getMBeanInfo()", "modelMBeanInfo is null");
            }
            this.modelMBeanInfo = this.createDefaultModelMBeanInfo();
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getMBeanInfo()", "ModelMBeanInfo is " + this.modelMBeanInfo.getClassName() + " for " + this.modelMBeanInfo.getDescription());
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getMBeanInfo()", this.printModelMBeanInfo(this.modelMBeanInfo));
        }
        return (MBeanInfo)this.modelMBeanInfo.clone();
    }
    
    private String printModelMBeanInfo(ModelMBeanInfo modelMBeanInfo) {
        StringBuilder sb = new StringBuilder();
        if (modelMBeanInfo == null) {
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "printModelMBeanInfo(ModelMBeanInfo)", "ModelMBeanInfo to print is null, printing local ModelMBeanInfo");
            }
            modelMBeanInfo = this.modelMBeanInfo;
        }
        sb.append("\nMBeanInfo for ModelMBean is:");
        sb.append("\nCLASSNAME: \t" + modelMBeanInfo.getClassName());
        sb.append("\nDESCRIPTION: \t" + modelMBeanInfo.getDescription());
        try {
            sb.append("\nMBEAN DESCRIPTOR: \t" + modelMBeanInfo.getMBeanDescriptor());
        }
        catch (Exception ex) {
            sb.append("\nMBEAN DESCRIPTOR: \t is invalid");
        }
        sb.append("\nATTRIBUTES");
        MBeanAttributeInfo[] attributes = modelMBeanInfo.getAttributes();
        if (attributes != null && attributes.length > 0) {
            for (int i = 0; i < attributes.length; ++i) {
                ModelMBeanAttributeInfo modelMBeanAttributeInfo = (ModelMBeanAttributeInfo)attributes[i];
                sb.append(" ** NAME: \t" + modelMBeanAttributeInfo.getName());
                sb.append("    DESCR: \t" + modelMBeanAttributeInfo.getDescription());
                sb.append("    TYPE: \t" + modelMBeanAttributeInfo.getType() + "    READ: \t" + modelMBeanAttributeInfo.isReadable() + "    WRITE: \t" + modelMBeanAttributeInfo.isWritable());
                sb.append("    DESCRIPTOR: " + modelMBeanAttributeInfo.getDescriptor().toString());
            }
        }
        else {
            sb.append(" ** No attributes **");
        }
        sb.append("\nCONSTRUCTORS");
        MBeanConstructorInfo[] constructors = modelMBeanInfo.getConstructors();
        if (constructors != null && constructors.length > 0) {
            for (int j = 0; j < constructors.length; ++j) {
                ModelMBeanConstructorInfo modelMBeanConstructorInfo = (ModelMBeanConstructorInfo)constructors[j];
                sb.append(" ** NAME: \t" + modelMBeanConstructorInfo.getName());
                sb.append("    DESCR: \t" + modelMBeanConstructorInfo.getDescription());
                sb.append("    PARAM: \t" + modelMBeanConstructorInfo.getSignature().length + " parameter(s)");
                sb.append("    DESCRIPTOR: " + modelMBeanConstructorInfo.getDescriptor().toString());
            }
        }
        else {
            sb.append(" ** No Constructors **");
        }
        sb.append("\nOPERATIONS");
        MBeanOperationInfo[] operations = modelMBeanInfo.getOperations();
        if (operations != null && operations.length > 0) {
            for (int k = 0; k < operations.length; ++k) {
                ModelMBeanOperationInfo modelMBeanOperationInfo = (ModelMBeanOperationInfo)operations[k];
                sb.append(" ** NAME: \t" + modelMBeanOperationInfo.getName());
                sb.append("    DESCR: \t" + modelMBeanOperationInfo.getDescription());
                sb.append("    PARAM: \t" + modelMBeanOperationInfo.getSignature().length + " parameter(s)");
                sb.append("    DESCRIPTOR: " + modelMBeanOperationInfo.getDescriptor().toString());
            }
        }
        else {
            sb.append(" ** No operations ** ");
        }
        sb.append("\nNOTIFICATIONS");
        MBeanNotificationInfo[] notifications = modelMBeanInfo.getNotifications();
        if (notifications != null && notifications.length > 0) {
            for (int l = 0; l < notifications.length; ++l) {
                ModelMBeanNotificationInfo modelMBeanNotificationInfo = (ModelMBeanNotificationInfo)notifications[l];
                sb.append(" ** NAME: \t" + modelMBeanNotificationInfo.getName());
                sb.append("    DESCR: \t" + modelMBeanNotificationInfo.getDescription());
                sb.append("    DESCRIPTOR: " + modelMBeanNotificationInfo.getDescriptor().toString());
            }
        }
        else {
            sb.append(" ** No notifications **");
        }
        sb.append(" ** ModelMBean: End of MBeanInfo ** ");
        return sb.toString();
    }
    
    @Override
    public Object invoke(String s, Object[] array, String[] array2) throws MBeanException, ReflectionException {
        int loggable = JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER);
        if (!(loggable == 0)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String, Object[], String[])", "Entry");
        }
        if (s == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("Method name must not be null"), "An exception occurred while trying to invoke a method on a RequiredModelMBean");
        }
        final String substring = null;
        int lastIndex = s.lastIndexOf(".");
        String str;
        if (lastIndex > 0) {
            substring = s.substring(0, lastIndex);
            str = s.substring(lastIndex + 1);
        }
        else {
            str = s;
        }
        int index = str.indexOf("(");
        if (index > 0) {
            str = str.substring(0, index);
        }
        if (!(loggable == 0)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String, Object[], String[])", "Finding operation " + s + " as " + str);
        }
        ModelMBeanOperationInfo operation = this.modelMBeanInfo.getOperation(str);
        if (operation == null) {
            String string2 = "Operation " + s + " not in ModelMBeanInfo";
            throw new MBeanException(new ServiceNotFoundException(string2), string2);
        }
        Descriptor descriptor = operation.getDescriptor();
        if (descriptor == null) {
            throw new MBeanException(new ServiceNotFoundException("Operation descriptor null"), "Operation descriptor null");
        }
        Object resolveForCacheValue = this.resolveForCacheValue(descriptor);
        if (resolveForCacheValue != null) {
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String, Object[], String[])", "Returning cached value");
                return resolveForCacheValue;
            }
            return resolveForCacheValue;
        }
        else {
            if (substring == null) {
                substring = (String)descriptor.getFieldValue("class");
            }
            String str2 = (String)descriptor.getFieldValue("name");
            if (str2 == null) {
                throw new MBeanException(new ServiceNotFoundException("Method descriptor must include `name' field"), "Method descriptor must include `name' field");
            }
            String str3 = (String)descriptor.getFieldValue("targetType");
            if (str3 != null && !str3.equalsIgnoreCase("objectReference")) {
                String string = "Target type must be objectReference: " + str3;
                throw new MBeanException(new InvalidTargetObjectTypeException(string), string);
            }
            Object fieldValue = descriptor.getFieldValue("targetObject");
            if (loggable && fieldValue != null) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String, Object[], String[])", "Found target object in descriptor");
            }
            Method method = this.findRMMBMethod(str2, fieldValue, substring, array2);
            if (method != null) {
            }
            else {
                if (!(loggable == 0)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String, Object[], String[])", "looking for method in managedResource class");
                }
                if (fieldValue != null) {
                    this = fieldValue;
                }
                else {
                    this = this.managedResource;
                    if (this == null) {
                        throw new MBeanException(new ServiceNotFoundException("managedResource for invoke " + s + " is null"));
                    }
                }
                Class<Object> class1;
                if (substring != null) {
                    try {
                        AccessControlContext context = AccessController.getContext();
                        final ClassNotFoundException[] array3 = { null };
                        class1 = (Class)RequiredModelMBean.javaSecurityAccess.doIntersectionPrivilege(new PrivilegedAction<Class<?>>() {
                            
                            @Override
                            public Class<?> run() {
                                try {
                                    ReflectUtil.checkPackageAccess(substring);
                                    return Class.forName(substring, false, obj.getClass().getClassLoader());
                                }
                                catch (ClassNotFoundException ex) {
                                    array3[0] = ex;
                                    return null;
                                }
                            }
                        }, context, this.acc);
                        if (array3[0] != null) {
                            throw array3[0];
                        }
                    }
                    catch (ClassNotFoundException e) {
                        throw new ReflectionException(e, "class for invoke " + s + " not found");
                    }
                }
                else {
                    class1 = this.getClass();
                }
                method = this.resolveMethod(class1, str2, array2);
            }
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String, Object[], String[])", "found " + str2 + ", now invoking");
            }
            Object invokeMethod = this.invokeMethod(s, method, this, array);
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String, Object[], String[])", "successfully invoked method");
            }
            if (invokeMethod != null) {
                this.cacheResult(operation, descriptor, invokeMethod);
                return invokeMethod;
            }
            return invokeMethod;
        }
    }
    
    private Method resolveMethod(Class<?> clazz, String str, final String[] array) throws ReflectionException {
        final int loggable = JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER);
        if (!(loggable == 0)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveMethod", "resolving " + clazz.getName() + "." + str);
        }
        final Class[] parameterTypes;
        if (array == null) {
            parameterTypes = null;
        }
        else {
            AccessControlContext context = AccessController.getContext();
            final ReflectionException[] array2 = { null };
            final ClassLoader classLoader = clazz.getClassLoader();
            parameterTypes = new Class[array.length];
            RequiredModelMBean.javaSecurityAccess.doIntersectionPrivilege(new PrivilegedAction<Void>() {
                @Override
                public Void run() {
                    for (int i = 0; i < array.length; ++i) {
                        if (!(loggable == 0)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveMethod", "resolve type " + array[i]);
                        }
                        parameterTypes[i] = (Class)RequiredModelMBean.primitiveClassMap.get(array[i]);
                        if (parameterTypes[i] == null) {
                            try {
                                ReflectUtil.checkPackageAccess(array[i]);
                                parameterTypes[i] = Class.forName(array[i], false, classLoader);
                            }
                            catch (ClassNotFoundException e) {
                                if (!(loggable == 0)) {
                                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "resolveMethod", "class not found");
                                }
                                array2[0] = new ReflectionException(e, "Parameter class not found");
                            }
                        }
                    }
                    return null;
                }
            }, context, this.acc);
            if (array2[0] != null) {
                throw array2[0];
            }
        }
        try {
            return clazz.getMethod(str, parameterTypes);
        }
        catch (NoSuchMethodException e) {
            throw new ReflectionException(e, "Target method not found: " + clazz.getName() + "." + str);
        }
    }
    
    private Method findRMMBMethod(String s, Object o, final String s2, String[] array) {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String, Object[], String[])", "looking for method in RequiredModelMBean class");
        }
        if (!isRMMBMethodName(s)) {
            return null;
        }
        if (o != null) {
            return null;
        }
        final Class<Object> clazz = RequiredModelMBean.class;
        if (s2 == null) {
        }
        else {
            AccessControlContext context = AccessController.getContext();
            clazz = (Class)RequiredModelMBean.javaSecurityAccess.doIntersectionPrivilege(new PrivilegedAction<Class<?>>() {
                @Override
                public Class<?> run() {
                    try {
                        ReflectUtil.checkPackageAccess(s2);
                        Class<Object> forName = Class.forName(s2, false, clazz.getClassLoader());
                        if (!clazz.isAssignableFrom(forName)) {
                            return null;
                        }
                        return forName;
                    }
                    catch (ClassNotFoundException ex) {
                        return null;
                    }
                }
            }, context, this.acc);
        }
        try {
            return (clazz != null) ? this.resolveMethod(clazz, s, array) : null;
        }
        catch (ReflectionException ex) {
            return null;
        }
    }
    
    private Object invokeMethod(String s, final Method method, final Object o, final Object[] array) throws MBeanException, ReflectionException {
        try {
            final Throwable[] array2 = { null };
            Object doIntersectionPrivilege = RequiredModelMBean.javaSecurityAccess.doIntersectionPrivilege(new PrivilegedAction<Object>() {
                @Override
                public Object run() {
                    try {
                        ReflectUtil.checkPackageAccess(method.getDeclaringClass());
                        return MethodUtil.invoke(method, o, array);
                    }
                    catch (InvocationTargetException ex) {
                        array2[0] = ex;
                    }
                    catch (IllegalAccessException ex2) {
                        array2[0] = ex2;
                    }
                    return null;
                }
            }, AccessController.getContext(), this.acc);
            if (array2[0] != null) {
                if ((array2[0] instanceof Exception)) {
                    throw (Exception)array2[0];
                }
                if ((array2[0] instanceof Error)) {
                    throw (Error)array2[0];
                }
            }
            return doIntersectionPrivilege;
        }
        catch (RuntimeErrorException e) {
            throw new RuntimeOperationsException(e, "RuntimeException occurred in RequiredModelMBean while trying to invoke operation " + s);
        }
        catch (RuntimeException e2) {
            throw new RuntimeOperationsException(e2, "RuntimeException occurred in RequiredModelMBean while trying to invoke operation " + s);
        }
        catch (IllegalAccessException e3) {
            throw new ReflectionException(e3, "IllegalAccessException occurred in RequiredModelMBean while trying to invoke operation " + s);
        }
        catch (InvocationTargetException ex) {
            Throwable targetException = ex.getTargetException();
            if ((targetException instanceof RuntimeException)) {
                throw new MBeanException((RuntimeException)targetException, "RuntimeException thrown in RequiredModelMBean while trying to invoke operation " + s);
            }
            if ((targetException instanceof Error)) {
                throw new RuntimeErrorException((Error)targetException, "Error occurred in RequiredModelMBean while trying to invoke operation " + s);
            }
            if ((targetException instanceof ReflectionException)) {
                throw (ReflectionException)targetException;
            }
            throw new MBeanException((Exception)targetException, "Exception thrown in RequiredModelMBean while trying to invoke operation " + s);
        }
        catch (Error e4) {
            throw new RuntimeErrorException(e4, "Error occurred in RequiredModelMBean while trying to invoke operation " + s);
        }
        catch (Exception e5) {
            throw new ReflectionException(e5, "Exception occurred in RequiredModelMBean while trying to invoke operation " + s);
        }
    }
    
    private void cacheResult(ModelMBeanOperationInfo modelMBeanOperationInfo, Descriptor obj, Object o) throws MBeanException {
        Descriptor mBeanDescriptor = this.modelMBeanInfo.getMBeanDescriptor();
        Object fieldValue = obj.getFieldValue("currencyTimeLimit");
        String s;
        if (fieldValue != null) {
            s = fieldValue.toString();
        }
        else {
            s = null;
        }
        if (s == null && mBeanDescriptor != null) {
            Object fieldValue2 = mBeanDescriptor.getFieldValue("currencyTimeLimit");
            if (fieldValue2 != null) {
                s = fieldValue2.toString();
            }
            else {
                s = null;
            }
        }
        if (s != null && !s.equals("-1")) {
            obj.setField("value", o);
            obj.setField("lastUpdatedTimeStamp", String.valueOf(new Date().getTime()));
            this.modelMBeanInfo.setDescriptor(obj, "operation");
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "invoke(String,Object[],Object[])", "new descriptor is " + obj);
            }
        }
    }
    
    private static synchronized boolean isRMMBMethodName(String s) {
        if (RequiredModelMBean.rmmbMethodNames == null) {
            try {
                HashSet<String> rmmbMethodNames = new HashSet();
                Method[] methods = RequiredModelMBean.class.getMethods();
                for (int i = 0; i < methods.length; ++i) {
                    rmmbMethodNames.add(methods[i].getName());
                }
                RequiredModelMBean.rmmbMethodNames = rmmbMethodNames;
            }
            catch (Exception ex) {
                return true;
            }
        }
        return RequiredModelMBean.rmmbMethodNames.contains(s);
    }
    
    @Override
    public Object getAttribute(String str) throws AttributeNotFoundException, MBeanException, ReflectionException {
        if (str == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("attributeName must not be null"), "Exception occurred trying to get attribute of a RequiredModelMBean");
        }
        int loggable = JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER);
        if (!(loggable == 0)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "Entry with " + str);
        }
        Object obj;
        try {
            if (this.modelMBeanInfo == null) {
                throw new AttributeNotFoundException("getAttribute failed: ModelMBeanInfo not found for " + str);
            }
            ModelMBeanAttributeInfo attribute = this.modelMBeanInfo.getAttribute(str);
            Descriptor mBeanDescriptor = this.modelMBeanInfo.getMBeanDescriptor();
            if (attribute == null) {
                throw new AttributeNotFoundException("getAttribute failed: ModelMBeanAttributeInfo not found for " + str);
            }
            Descriptor descriptor = attribute.getDescriptor();
            if (descriptor != null) {
                if (!attribute.isReadable()) {
                    throw new AttributeNotFoundException("getAttribute failed: " + str + " is not readable ");
                }
                obj = this.resolveForCacheValue(descriptor);
                if (!(loggable == 0)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "*** cached value is " + obj);
                }
                if (obj == null) {
                    if (!(loggable == 0)) {
                        JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "**** cached value is null - getting getMethod");
                    }
                    String s = (String)(String)descriptor.getFieldValue("getMethod");
                    if (s != null) {
                        if (!(loggable == 0)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "invoking a getMethod for " + str);
                        }
                        Object invoke = this.invoke(s, new Object[0], new String[0]);
                        if (invoke != null) {
                            if (!(loggable == 0)) {
                                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "got a non-null response from getMethod\n");
                            }
                            obj = invoke;
                            Object fieldValue = descriptor.getFieldValue("currencyTimeLimit");
                            String s2;
                            if (fieldValue != null) {
                                s2 = fieldValue.toString();
                            }
                            else {
                                s2 = null;
                            }
                            if (s2 == null && mBeanDescriptor != null) {
                                Object fieldValue2 = mBeanDescriptor.getFieldValue("currencyTimeLimit");
                                if (fieldValue2 != null) {
                                    s2 = fieldValue2.toString();
                                }
                                else {
                                    s2 = null;
                                }
                            }
                            if (s2 != null && !s2.equals("-1")) {
                                if (!(loggable == 0)) {
                                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "setting cached value and lastUpdatedTime in descriptor");
                                }
                                descriptor.setField("value", obj);
                                descriptor.setField("lastUpdatedTimeStamp", String.valueOf(new Date().getTime()));
                                attribute.setDescriptor(descriptor);
                                this.modelMBeanInfo.setDescriptor(descriptor, "attribute");
                                if (!(loggable == 0)) {
                                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "new descriptor is " + descriptor);
                                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "AttributeInfo descriptor is " + attribute.getDescriptor());
                                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "modelMBeanInfo: AttributeInfo descriptor is " + this.modelMBeanInfo.getDescriptor(str, "attribute").toString());
                                }
                            }
                        }
                        else {
                            if (!(loggable == 0)) {
                                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "got a null response from getMethod\n");
                            }
                            obj = null;
                        }
                    }
                    else {
                        String str2 = "";
                        obj = descriptor.getFieldValue("value");
                        if (obj == null) {
                            str2 = "default ";
                            obj = descriptor.getFieldValue("default");
                        }
                        if (!(loggable == 0)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "could not find getMethod for " + str + ", returning descriptor " + str2 + "value");
                        }
                    }
                }
                final String type = attribute.getType();
                if (obj != null) {
                    String name = obj.getClass().getName();
                    if (!type.equals(name)) {
                        boolean n = false;
                        boolean n2 = false;
                        boolean n3 = false;
                        int i = 0;
                        while (i < RequiredModelMBean.primitiveTypes.length) {
                            if (type.equals(RequiredModelMBean.primitiveTypes[i])) {
                                n2 = true;
                                if (name.equals(RequiredModelMBean.primitiveWrappers[i])) {
                                    n3 = true;
                                    break;
                                }
                                break;
                            }
                            else {
                                ++i;
                            }
                        }
                        if (!(n2 == 0)) {
                            if (n3 == 0) {
                                n = true;
                            }
                        }
                        else {
                            int instance;
                            try {
                                final Class<Object> class1 = obj.getClass();
                                final Exception[] array = { null };
                                Class<Object> clazz = (Class)RequiredModelMBean.javaSecurityAccess.doIntersectionPrivilege(new PrivilegedAction<Class<?>>() {
                                    @Override
                                    public Class<?> run() {
                                        try {
                                            ReflectUtil.checkPackageAccess(type);
                                            return Class.forName(type, true, class1.getClassLoader());
                                        }
                                        catch (Exception ex) {
                                            array[0] = ex;
                                            return null;
                                        }
                                    }
                                }, AccessController.getContext(), this.acc);
                                if (array[0] != null) {
                                    throw array[0];
                                }
                                instance = clazz.isInstance(obj);
                            }
                            catch (Exception thrown) {
                                instance = false;
                                if (!(loggable == 0)) {
                                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "Exception: ", thrown);
                                }
                            }
                            if (instance == 0) {
                                n = true;
                            }
                        }
                        if (!(n == 0)) {
                            if (!(loggable == 0)) {
                                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "Wrong response type '" + type + "'");
                            }
                            throw new MBeanException(new InvalidAttributeValueException("Wrong value type received for get attribute"), "An exception occurred while trying to get an attribute value through a RequiredModelMBean");
                        }
                    }
                }
            }
            else {
                if (!(loggable == 0)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "getMethod failed " + str + " not in attributeDescriptor\n");
                }
                throw new MBeanException(new InvalidAttributeValueException("Unable to resolve attribute value, no getMethod defined in descriptor for attribute"), "An exception occurred while trying to get an attribute value through a RequiredModelMBean");
            }
        }
        catch (MBeanException ex) {
            throw ex;
        }
        catch (AttributeNotFoundException ex2) {
            throw ex2;
        }
        catch (Exception e) {
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "getMethod failed with " + e.getMessage() + " exception type " + e.getClass().toString());
            }
            throw new MBeanException(e, "An exception occurred while trying to get an attribute value: " + e.getMessage());
        }
        if (!(loggable == 0)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttribute(String)", "Exit");
            return obj;
        }
        return obj;
    }
    
    @Override
    public AttributeList getAttributes(String[] array) {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttributes(String[])", "Entry");
        }
        if (array == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("attributeNames must not be null"), "Exception occurred trying to get attributes of a RequiredModelMBean");
        }
        AttributeList list = new AttributeList();
        for (int i = 0; i < array.length; ++i) {
            try {
                list.add(new Attribute(array[i], this.getAttribute(array[i])));
            }
            catch (Exception thrown) {
                if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttributes(String[])", "Failed to get \"" + array[i] + "\": ", thrown);
                }
            }
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getAttributes(String[])", "Exit");
            return list;
        }
        return list;
    }
    
    @Override
    public void setAttribute(Attribute attribute) throws AttributeNotFoundException, InvalidAttributeValueException, MBeanException, ReflectionException {
        int loggable = JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER);
        if (!(loggable == 0)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setAttribute()", "Entry");
        }
        if (attribute == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("attribute must not be null"), "Exception occurred trying to set an attribute of a RequiredModelMBean");
        }
        String name = attribute.getName();
        Object value = attribute.getValue();
        boolean n = false;
        ModelMBeanAttributeInfo attribute2 = this.modelMBeanInfo.getAttribute(name);
        if (attribute2 == null) {
            throw new AttributeNotFoundException("setAttribute failed: " + name + " is not found ");
        }
        Descriptor mBeanDescriptor = this.modelMBeanInfo.getMBeanDescriptor();
        Descriptor descriptor = attribute2.getDescriptor();
        if (descriptor != null) {
            if (!attribute2.isWritable()) {
                throw new AttributeNotFoundException("setAttribute failed: " + name + " is not writable ");
            }
            String s = (String)(String)descriptor.getFieldValue("setMethod");
            String s2 = (String)(String)descriptor.getFieldValue("getMethod");
            String type = attribute2.getType();
            String attribute3 = "Unknown";
            try {
                attribute3 = this.getAttribute(name);
            }
            catch (Throwable t) {}
            Attribute o = new Attribute(name, attribute3);
            if (s == null) {
                if (value != null) {
                    try {
                        Class<Object> loadClass = this.loadClass(type);
                        if (!loadClass.isInstance(value)) {
                            throw new InvalidAttributeValueException(loadClass.getName() + " expected, " + value.getClass().getName() + " received.");
                        }
                    }
                    catch (ClassNotFoundException thrown) {
                        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setAttribute(Attribute)", "Class " + type + " for attribute " + name + " not found: ", thrown);
                        }
                    }
                }
                n = true;
            }
            else {
                this.invoke(s, new Object[] { value }, new String[] { type });
            }
            Object fieldValue = descriptor.getFieldValue("currencyTimeLimit");
            String s3;
            if (fieldValue != null) {
                s3 = fieldValue.toString();
            }
            else {
                s3 = null;
            }
            if (s3 == null && mBeanDescriptor != null) {
                Object fieldValue2 = mBeanDescriptor.getFieldValue("currencyTimeLimit");
                if (fieldValue2 != null) {
                    s3 = fieldValue2.toString();
                }
                else {
                    s3 = null;
                }
            }
            int n2 = s3 != null && !s3.equals("-1");
            if (s == null && n2 == 0 && s2 != null) {
                throw new MBeanException(new ServiceNotFoundException("No setMethod field is defined in the descriptor for " + name + " attribute and caching is not enabled for it"));
            }
            if (n2 || n) {
                if (!(loggable == 0)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setAttribute(Attribute)", "setting cached value of " + name + " to " + value);
                }
                descriptor.setField("value", value);
                if (!(n2 == 0)) {
                    descriptor.setField("lastUpdatedTimeStamp", String.valueOf(new Date().getTime()));
                }
                attribute2.setDescriptor(descriptor);
                this.modelMBeanInfo.setDescriptor(descriptor, "attribute");
                if (!(loggable == 0)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setAttribute(Attribute)", "new descriptor is " + descriptor + ". AttributeInfo descriptor is " + attribute2.getDescriptor() + ". AttributeInfo descriptor is " + this.modelMBeanInfo.getDescriptor(name, "attribute"));
                }
            }
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setAttribute(Attribute)", "sending sendAttributeNotification");
            }
            this.sendAttributeChangeNotification(o, attribute);
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setAttribute(Attribute)", "Exit");
            }
            return;
        }
        else {
            if (!(loggable == 0)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setAttribute(Attribute)", "setMethod failed " + name + " not in attributeDescriptor\n");
            }
            throw new InvalidAttributeValueException("Unable to resolve attribute value, no defined in descriptor for attribute");
        }
    }
    
    @Override
    public AttributeList setAttributes(AttributeList list) {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "setAttribute(Attribute)", "Entry");
        }
        if (list == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("attributes must not be null"), "Exception occurred trying to set attributes of a RequiredModelMBean");
        }
        AttributeList list2 = new AttributeList();
        for (Attribute o : list.asList()) {
            try {
                this.setAttribute(o);
                list2.add(o);
            }
            catch (Exception ex) {
                list2.remove(o);
            }
        }
        return list2;
    }
    
    private ModelMBeanInfo createDefaultModelMBeanInfo() {
        return new ModelMBeanInfoSupport(this.getClass().getName(), "Default ModelMBean", null, null, null, null);
    }
    
    private synchronized void writeToLog(String s, String s2) throws Exception {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "writeToLog(String, String)", "Notification Logging to " + s + ": " + s2);
        }
        if (s == null || s2 == null) {
            if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "writeToLog(String, String)", "Bad input parameters, will not log this entry.");
            }
            return;
        }
        else {
            FileOutputStream out = new FileOutputStream(s, true);
            try {
                PrintStream printStream = new PrintStream(out);
                printStream.println(s2);
                printStream.close();
                if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "writeToLog(String, String)", "Successfully opened log " + s);
                }
            }
            catch (Exception ex) {
                if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
                    JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "writeToLog(String, String)", "Exception " + ex.toString() + " trying to write to the Notification log file " + s);
                }
                throw ex;
            }
            finally {
                out.close();
            }
            return;
        }
    }
    
    @Override
    public void addNotificationListener(NotificationListener listener, NotificationFilter filter, Object handback) throws IllegalArgumentException {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "addNotificationListener(NotificationListener, NotificationFilter, Object)", "Entry");
        }
        if (listener == null) {
            throw new IllegalArgumentException("notification listener must not be null");
        }
        if (this.generalBroadcaster == null) {
            this.generalBroadcaster = new NotificationBroadcasterSupport();
        }
        this.generalBroadcaster.addNotificationListener(listener, filter, handback);
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "addNotificationListener(NotificationListener, NotificationFilter, Object)", "NotificationListener added");
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "addNotificationListener(NotificationListener, NotificationFilter, Object)", "Exit");
        }
        return;
    }
    
    @Override
    public void removeNotificationListener(NotificationListener listener) throws ListenerNotFoundException {
        if (listener == null) {
            throw new ListenerNotFoundException("Notification listener is null");
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "removeNotificationListener(NotificationListener)", "Entry");
        }
        if (this.generalBroadcaster == null) {
            throw new ListenerNotFoundException("No notification listeners registered");
        }
        this.generalBroadcaster.removeNotificationListener(listener);
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "removeNotificationListener(NotificationListener)", "Exit");
        }
        return;
    }
    
    @Override
    public void removeNotificationListener(NotificationListener listener, NotificationFilter filter, Object handback) throws ListenerNotFoundException {
        if (listener == null) {
            throw new ListenerNotFoundException("Notification listener is null");
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "removeNotificationListener(NotificationListener, NotificationFilter, Object)", "Entry");
        }
        if (this.generalBroadcaster == null) {
            throw new ListenerNotFoundException("No notification listeners registered");
        }
        this.generalBroadcaster.removeNotificationListener(listener, filter, handback);
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "removeNotificationListener(NotificationListener, NotificationFilter, Object)", "Exit");
        }
        return;
    }
    
    @Override
    public void sendNotification(Notification notification) throws MBeanException, RuntimeOperationsException {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendNotification(Notification)", "Entry");
        }
        if (notification == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("notification object must not be null"), "Exception occurred trying to send a notification from a RequiredModelMBean");
        }
        Descriptor descriptor = this.modelMBeanInfo.getDescriptor(notification.getType(), "notification");
        Descriptor mBeanDescriptor = this.modelMBeanInfo.getMBeanDescriptor();
        if (descriptor != null) {
            String s = (String)descriptor.getFieldValue("log");
            if (s == null && mBeanDescriptor != null) {
                s = (String)mBeanDescriptor.getFieldValue("log");
            }
            if (s != null && (s.equalsIgnoreCase("t") || s.equalsIgnoreCase("true"))) {
                String s2 = (String)descriptor.getFieldValue("logfile");
                if (s2 == null && mBeanDescriptor != null) {
                    s2 = (String)mBeanDescriptor.getFieldValue("logfile");
                }
                if (s2 != null) {
                    try {
                        this.writeToLog(s2, "LogMsg: " + new Date(notification.getTimeStamp()).toString() + " " + notification.getType() + " " + notification.getMessage() + " Severity = " + (String)descriptor.getFieldValue("severity"));
                    }
                    catch (Exception thrown) {
                        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINE)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINE, RequiredModelMBean.class.getName(), "sendNotification(Notification)", "Failed to log " + notification.getType() + " notification: ", thrown);
                        }
                    }
                }
            }
        }
        if (this.generalBroadcaster != null) {
            this.generalBroadcaster.sendNotification(notification);
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendNotification(Notification)", "sendNotification sent provided notification object");
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendNotification(Notification)", " Exit");
        }
        return;
    }
    
    @Override
    public void sendNotification(String message) throws MBeanException, RuntimeOperationsException {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendNotification(String)", "Entry");
        }
        if (message == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("notification message must not be null"), "Exception occurred trying to send a text notification from a ModelMBean");
        }
        this.sendNotification(new Notification("jmx.modelmbean.generic", this, 1L, message));
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendNotification(String)", "Notification sent");
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendNotification(String)", "Exit");
        }
        return;
    }
    
    private static final boolean hasNotification(ModelMBeanInfo modelMBeanInfo, String s) {
        try {
            return modelMBeanInfo != null && modelMBeanInfo.getNotification(s) != null;
        }
        catch (MBeanException ex) {
            return false;
        }
        catch (RuntimeOperationsException ex2) {
            return false;
        }
    }
    
    private static final ModelMBeanNotificationInfo makeGenericInfo() {
        return new ModelMBeanNotificationInfo(new String[] { "jmx.modelmbean.generic" }, "GENERIC", "A text notification has been issued by the managed resource", new DescriptorSupport(new String[] { "name=GENERIC", "descriptorType=notification", "log=T", "severity=6", "displayName=jmx.modelmbean.generic" }));
    }
    
    private static final ModelMBeanNotificationInfo makeAttributeChangeInfo() {
        return new ModelMBeanNotificationInfo(new String[] { "jmx.attribute.change" }, "ATTRIBUTE_CHANGE", "Signifies that an observed MBean attribute value has changed", new DescriptorSupport(new String[] { "name=ATTRIBUTE_CHANGE", "descriptorType=notification", "log=T", "severity=6", "displayName=jmx.attribute.change" }));
    }
    
    @Override
    public MBeanNotificationInfo[] getNotificationInfo() {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getNotificationInfo()", "Entry");
        }
        int hasNotification = hasNotification(this.modelMBeanInfo, "GENERIC");
        int hasNotification2 = hasNotification(this.modelMBeanInfo, "ATTRIBUTE_CHANGE");
        ModelMBeanNotificationInfo[] array = (ModelMBeanNotificationInfo[])(ModelMBeanNotificationInfo[])this.modelMBeanInfo.getNotifications();
        ModelMBeanNotificationInfo[] array2 = new ModelMBeanNotificationInfo[((array == null) ? 0 : array.length) + (hasNotification ? 0 : 1) + (hasNotification2 ? 0 : 1)];
        int n = 0;
        if (hasNotification == 0) {
            array2[n++] = makeGenericInfo();
        }
        if (hasNotification2 == 0) {
            array2[n++] = makeAttributeChangeInfo();
        }
        int length = array.length;
        for (int i = 0; i < length; ++i) {
            array2[n + i] = array[i];
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "getNotificationInfo()", "Exit");
            return array2;
        }
        return array2;
    }
    
    @Override
    public void addAttributeChangeNotificationListener(NotificationListener listener, String s, Object handback) throws MBeanException, RuntimeOperationsException, IllegalArgumentException {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "addAttributeChangeNotificationListener(NotificationListener, String, Object)", "Entry");
        }
        if (listener == null) {
            throw new IllegalArgumentException("Listener to be registered must not be null");
        }
        if (this.attributeBroadcaster == null) {
            this.attributeBroadcaster = new NotificationBroadcasterSupport();
        }
        AttributeChangeNotificationFilter filter = new AttributeChangeNotificationFilter();
        MBeanAttributeInfo[] attributes = this.modelMBeanInfo.getAttributes();
        boolean n = false;
        if (s == null) {
            if (attributes != null && attributes.length > 0) {
                for (int j = 0; j < attributes.length; ++j) {
                    filter.enableAttribute(attributes[j].getName());
                }
            }
        }
        else {
            if (attributes != null && attributes.length > 0) {
                int i = 0;
                while (i < attributes.length) {
                    if (s.equals(attributes[i].getName())) {
                        n = true;
                        filter.enableAttribute(s);
                        break;
                    }
                    ++i;
                }
            }
            if (n == 0) {
                throw new RuntimeOperationsException(new IllegalArgumentException("The attribute name does not exist"), "Exception occurred trying to add an AttributeChangeNotification listener");
            }
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            Vector<String> enabledAttributes = filter.getEnabledAttributes();
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "addAttributeChangeNotificationListener(NotificationListener, String, Object)", "Set attribute change filter to " + ((enabledAttributes.size() > 1) ? ("[" + (String)enabledAttributes.firstElement() + ", ...]") : enabledAttributes.toString()));
        }
        this.attributeBroadcaster.addNotificationListener(listener, filter, handback);
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "addAttributeChangeNotificationListener(NotificationListener, String, Object)", "Notification listener added for " + s);
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "addAttributeChangeNotificationListener(NotificationListener, String, Object)", "Exit");
        }
        return;
    }
    
    @Override
    public void removeAttributeChangeNotificationListener(NotificationListener listener, String anObject) throws MBeanException, RuntimeOperationsException, ListenerNotFoundException {
        if (listener == null) {
            throw new ListenerNotFoundException("Notification listener is null");
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "removeAttributeChangeNotificationListener(NotificationListener, String)", "Entry");
        }
        if (this.attributeBroadcaster == null) {
            throw new ListenerNotFoundException("No attribute change notification listeners registered");
        }
        MBeanAttributeInfo[] attributes = this.modelMBeanInfo.getAttributes();
        boolean n = false;
        if (attributes != null && attributes.length > 0) {
            int i = 0;
            while (i < attributes.length) {
                if (attributes[i].getName().equals(anObject)) {
                    n = true;
                    break;
                }
                ++i;
            }
        }
        if (n == 0 && anObject != null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("Invalid attribute name"), "Exception occurred trying to remove attribute change notification listener");
        }
        this.attributeBroadcaster.removeNotificationListener(listener);
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "removeAttributeChangeNotificationListener(NotificationListener, String)", "Exit");
        }
        return;
    }
    
    @Override
    public void sendAttributeChangeNotification(AttributeChangeNotification attributeChangeNotification) throws MBeanException, RuntimeOperationsException {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendAttributeChangeNotification(AttributeChangeNotification)", "Entry");
        }
        if (attributeChangeNotification == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("attribute change notification object must not be null"), "Exception occurred trying to send attribute change notification of a ModelMBean");
        }
        Object oldValue = attributeChangeNotification.getOldValue();
        Object newValue = attributeChangeNotification.getNewValue();
        if (oldValue == null) {
            oldValue = "null";
        }
        if (newValue == null) {
            newValue = "null";
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendAttributeChangeNotification(AttributeChangeNotification)", "Sending AttributeChangeNotification with " + attributeChangeNotification.getAttributeName() + attributeChangeNotification.getAttributeType() + attributeChangeNotification.getNewValue() + attributeChangeNotification.getOldValue());
        }
        Descriptor descriptor = this.modelMBeanInfo.getDescriptor(attributeChangeNotification.getType(), "notification");
        Descriptor mBeanDescriptor = this.modelMBeanInfo.getMBeanDescriptor();
        if (descriptor != null) {
            String s3 = (String)descriptor.getFieldValue("log");
            if (s3 == null && mBeanDescriptor != null) {
                s3 = (String)mBeanDescriptor.getFieldValue("log");
            }
            if (s3 != null && (s3.equalsIgnoreCase("t") || s3.equalsIgnoreCase("true"))) {
                String s4 = (String)descriptor.getFieldValue("logfile");
                if (s4 == null && mBeanDescriptor != null) {
                    s4 = (String)mBeanDescriptor.getFieldValue("logfile");
                }
                if (s4 != null) {
                    try {
                        this.writeToLog(s4, "LogMsg: " + new Date(attributeChangeNotification.getTimeStamp()).toString() + " " + attributeChangeNotification.getType() + " " + attributeChangeNotification.getMessage() + " Name = " + attributeChangeNotification.getAttributeName() + " Old value = " + oldValue + " New value = " + newValue);
                    }
                    catch (Exception thrown2) {
                        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINE)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINE, RequiredModelMBean.class.getName(), "sendAttributeChangeNotification(AttributeChangeNotification)", "Failed to log " + attributeChangeNotification.getType() + " notification: ", thrown2);
                        }
                    }
                }
            }
        }
        else if (mBeanDescriptor != null) {
            String s = (String)mBeanDescriptor.getFieldValue("log");
            if (s != null && (s.equalsIgnoreCase("t") || s.equalsIgnoreCase("true"))) {
                String s2 = (String)mBeanDescriptor.getFieldValue("logfile");
                if (s2 != null) {
                    try {
                        this.writeToLog(s2, "LogMsg: " + new Date(attributeChangeNotification.getTimeStamp()).toString() + " " + attributeChangeNotification.getType() + " " + attributeChangeNotification.getMessage() + " Name = " + attributeChangeNotification.getAttributeName() + " Old value = " + oldValue + " New value = " + newValue);
                    }
                    catch (Exception thrown) {
                        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINE)) {
                            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINE, RequiredModelMBean.class.getName(), "sendAttributeChangeNotification(AttributeChangeNotification)", "Failed to log " + attributeChangeNotification.getType() + " notification: ", thrown);
                        }
                    }
                }
            }
        }
        if (this.attributeBroadcaster != null) {
            this.attributeBroadcaster.sendNotification(attributeChangeNotification);
        }
        if (this.generalBroadcaster != null) {
            this.generalBroadcaster.sendNotification(attributeChangeNotification);
        }
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendAttributeChangeNotification(AttributeChangeNotification)", "sent notification");
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendAttributeChangeNotification(AttributeChangeNotification)", "Exit");
        }
        return;
    }
    
    @Override
    public void sendAttributeChangeNotification(Attribute attribute, Attribute attribute2) throws MBeanException, RuntimeOperationsException {
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendAttributeChangeNotification(Attribute, Attribute)", "Entry");
        }
        if (attribute == null || attribute2 == null) {
            throw new RuntimeOperationsException(new IllegalArgumentException("Attribute object must not be null"), "Exception occurred trying to send attribute change notification of a ModelMBean");
        }
        if (!attribute.getName().equals(attribute2.getName())) {
            throw new RuntimeOperationsException(new IllegalArgumentException("Attribute names are not the same"), "Exception occurred trying to send attribute change notification of a ModelMBean");
        }
        Object value = attribute2.getValue();
        Object value2 = attribute.getValue();
        String attributeType = "unknown";
        if (value != null) {
            attributeType = value.getClass().getName();
        }
        if (value2 != null) {
            attributeType = value2.getClass().getName();
        }
        this.sendAttributeChangeNotification(new AttributeChangeNotification(this, 1L, new Date().getTime(), "AttributeChangeDetected", attribute.getName(), attributeType, attribute.getValue(), attribute2.getValue()));
        if (JmxProperties.MODELMBEAN_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MODELMBEAN_LOGGER.logp(Level.FINER, RequiredModelMBean.class.getName(), "sendAttributeChangeNotification(Attribute, Attribute)", "Exit");
        }
        return;
    }
    
    protected ClassLoaderRepository getClassLoaderRepository() {
        return MBeanServerFactory.getClassLoaderRepository(this.server);
    }
    
    private Class<?> loadClass(final String s) throws ClassNotFoundException {
        AccessControlContext context = AccessController.getContext();
        final ClassNotFoundException[] array = { null };
        Class<Object> clazz = (Class)RequiredModelMBean.javaSecurityAccess.doIntersectionPrivilege(new PrivilegedAction<Class<?>>() {
            @Override
            public Class<?> run() {
                try {
                    ReflectUtil.checkPackageAccess(s);
                    return Class.forName(s);
                }
                catch (ClassNotFoundException ex) {
                    ClassLoaderRepository classLoaderRepository = RequiredModelMBean.this.getClassLoaderRepository();
                    try {
                        if (classLoaderRepository == null) {
                            throw new ClassNotFoundException(s);
                        }
                        return classLoaderRepository.loadClass(s);
                    }
                    catch (ClassNotFoundException ex2) {
                        array[0] = ex2;
                        return null;
                    }
                }
            }
        }, context, this.acc);
        if (array[0] != null) {
            throw array[0];
        }
        return clazz;
    }
    
    @Override
    public ObjectName preRegister(MBeanServer server, ObjectName objectName) throws Exception {
        if (objectName == null) {
            throw new NullPointerException("name of RequiredModelMBean to registered is null");
        }
        this.server = server;
        return objectName;
    }
    
    @Override
    public void postRegister(Boolean b) {
        this.registered = (boolean)b;
    }
    
    @Override
    public void preDeregister() throws Exception {
    }
    
    @Override
    public void postDeregister() {
        this.registered = false;
        this.server = null;
    }
    
    static {
        javaSecurityAccess = SharedSecrets.getJavaSecurityAccess();
        primitiveClasses = new Class[] { Integer.TYPE, Long.TYPE, Boolean.TYPE, Double.TYPE, Float.TYPE, Short.TYPE, Byte.TYPE, Character.TYPE };
        primitiveClassMap = new HashMap();
        for (int i = 0; i < RequiredModelMBean.primitiveClasses.length; ++i) {
            Class<Object> clazz = RequiredModelMBean.primitiveClasses[i];
            RequiredModelMBean.primitiveClassMap.put(clazz.getName(), clazz);
        }
        primitiveTypes = new String[] { Boolean.TYPE.getName(), Byte.TYPE.getName(), Character.TYPE.getName(), Short.TYPE.getName(), Integer.TYPE.getName(), Long.TYPE.getName(), Float.TYPE.getName(), Double.TYPE.getName(), Void.TYPE.getName() };
        primitiveWrappers = new String[] { Boolean.class.getName(), Byte.class.getName(), Character.class.getName(), Short.class.getName(), Integer.class.getName(), Long.class.getName(), Float.class.getName(), Double.class.getName(), Void.class.getName() };
    }
}
